==> kubernetes-model-extensions-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/DeploymentRollbackBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DeploymentRollbackBuilder extends io.fabric8.kubernetes.api.model.extensions.DeploymentRollbackFluentImpl<io.fabric8.kubernetes.api.model.extensions.DeploymentRollbackBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.extensions.DeploymentRollback,io.fabric8.kubernetes.api.model.extensions.DeploymentRollbackBuilder>{
  public DeploymentRollbackBuilder() {
    this(false);
  }
  public DeploymentRollbackBuilder(java.lang.Boolean validationEnabled) {
    this(new DeploymentRollback(), validationEnabled);
  }
  public DeploymentRollbackBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentRollbackFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentRollbackBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentRollbackFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DeploymentRollback(), validationEnabled);
  }
  public DeploymentRollbackBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentRollbackFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.DeploymentRollback instance) {
    this(fluent, instance, false);
  }
  public DeploymentRollbackBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentRollbackFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.DeploymentRollback instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    fluent.withRollbackTo(instance.getRollbackTo()); 
    fluent.withUpdatedAnnotations(instance.getUpdatedAnnotations()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DeploymentRollbackBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentRollback instance) {
    this(instance,false);
  }
  public DeploymentRollbackBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentRollback instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withRollbackTo(instance.getRollbackTo()); 
    this.withUpdatedAnnotations(instance.getUpdatedAnnotations()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.extensions.DeploymentRollbackFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.extensions.DeploymentRollback build() {
    DeploymentRollback buildable = new DeploymentRollback(fluent.getApiVersion(),fluent.getKind(),fluent.getName(),fluent.getRollbackTo(),fluent.getUpdatedAnnotations());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeploymentRollbackBuilder that = (DeploymentRollbackBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-extensions-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/extensions/DeploymentRollbackBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DeploymentRollbackBuilder extends DeploymentRollbackFluentImpl<DeploymentRollbackBuilder> implements VisitableBuilder<DeploymentRollback,DeploymentRollbackBuilder>{
  public DeploymentRollbackBuilder() {
    this(false);
  }
  public DeploymentRollbackBuilder(Boolean validationEnabled) {
    this(new DeploymentRollback(), validationEnabled);
  }
  public DeploymentRollbackBuilder(DeploymentRollbackFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentRollbackBuilder(DeploymentRollbackFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DeploymentRollback(), validationEnabled);
  }
  public DeploymentRollbackBuilder(DeploymentRollbackFluent<?> fluent,DeploymentRollback instance) {
    this(fluent, instance, false);
  }
  public DeploymentRollbackBuilder(DeploymentRollbackFluent<?> fluent,DeploymentRollback instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    fluent.withRollbackTo(instance.getRollbackTo()); 
    fluent.withUpdatedAnnotations(instance.getUpdatedAnnotations()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DeploymentRollbackBuilder(DeploymentRollback instance) {
    this(instance,false);
  }
  public DeploymentRollbackBuilder(DeploymentRollback instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withRollbackTo(instance.getRollbackTo()); 
    this.withUpdatedAnnotations(instance.getUpdatedAnnotations()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  DeploymentRollbackFluent<?> fluent;
  Boolean validationEnabled;
  public DeploymentRollback build() {
    DeploymentRollback buildable = new DeploymentRollback(fluent.getApiVersion(),fluent.getKind(),fluent.getName(),fluent.getRollbackTo(),fluent.getUpdatedAnnotations());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
